# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class UsageOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bytes': 'int',
        'cache_type': 'str',
        'calls': 'int',
        'content': 'int',
        'credits': 'float',
        'identity': 'str',
        'identity_id': 'str',
        'prompts': 'int',
        'source_label': 'str',
        'source_url': 'str',
        'timestamp': 'str',
        'tokens': 'int',
        'type': 'str'
    }

    attribute_map = {
        'bytes': 'bytes',
        'cache_type': 'cacheType',
        'calls': 'calls',
        'content': 'content',
        'credits': 'credits',
        'identity': 'identity',
        'identity_id': 'identityId',
        'prompts': 'prompts',
        'source_label': 'sourceLabel',
        'source_url': 'sourceUrl',
        'timestamp': 'timestamp',
        'tokens': 'tokens',
        'type': 'type'
    }

    def __init__(self, bytes=None, cache_type=None, calls=None, content=None, credits=None, identity=None, identity_id=None, prompts=None, source_label=None, source_url=None, timestamp=None, tokens=None, type=None):
        """
        UsageOutputV1 - a model defined in Swagger
        """

        self._bytes = None
        self._cache_type = None
        self._calls = None
        self._content = None
        self._credits = None
        self._identity = None
        self._identity_id = None
        self._prompts = None
        self._source_label = None
        self._source_url = None
        self._timestamp = None
        self._tokens = None
        self._type = None

        if bytes is not None:
          self.bytes = bytes
        if cache_type is not None:
          self.cache_type = cache_type
        if calls is not None:
          self.calls = calls
        if content is not None:
          self.content = content
        if credits is not None:
          self.credits = credits
        if identity is not None:
          self.identity = identity
        if identity_id is not None:
          self.identity_id = identity_id
        if prompts is not None:
          self.prompts = prompts
        if source_label is not None:
          self.source_label = source_label
        if source_url is not None:
          self.source_url = source_url
        if timestamp is not None:
          self.timestamp = timestamp
        if tokens is not None:
          self.tokens = tokens
        if type is not None:
          self.type = type

    @property
    def bytes(self):
        """
        Gets the bytes of this UsageOutputV1.
        Amount of data consumed during the specified time period, in bytes

        :return: The bytes of this UsageOutputV1.
        :rtype: int
        """
        return self._bytes

    @bytes.setter
    def bytes(self, bytes):
        """
        Sets the bytes of this UsageOutputV1.
        Amount of data consumed during the specified time period, in bytes

        :param bytes: The bytes of this UsageOutputV1.
        :type: int
        """
        if bytes is None:
            raise ValueError("Invalid value for `bytes`, must not be `None`")

        self._bytes = bytes

    @property
    def cache_type(self):
        """
        Gets the cache_type of this UsageOutputV1.
        The caching source that provided the data. Either Seeq's in-memory cache, Seeq's persistent cache, or the datasource itself if it was not yet cached. Only present when aggregated by \"CacheType\"

        :return: The cache_type of this UsageOutputV1.
        :rtype: str
        """
        return self._cache_type

    @cache_type.setter
    def cache_type(self, cache_type):
        """
        Sets the cache_type of this UsageOutputV1.
        The caching source that provided the data. Either Seeq's in-memory cache, Seeq's persistent cache, or the datasource itself if it was not yet cached. Only present when aggregated by \"CacheType\"

        :param cache_type: The cache_type of this UsageOutputV1.
        :type: str
        """

        self._cache_type = cache_type

    @property
    def calls(self):
        """
        Gets the calls of this UsageOutputV1.
        Amount of GenAI api calls consumed during the specified time period

        :return: The calls of this UsageOutputV1.
        :rtype: int
        """
        return self._calls

    @calls.setter
    def calls(self, calls):
        """
        Sets the calls of this UsageOutputV1.
        Amount of GenAI api calls consumed during the specified time period

        :param calls: The calls of this UsageOutputV1.
        :type: int
        """
        if calls is None:
            raise ValueError("Invalid value for `calls`, must not be `None`")

        self._calls = calls

    @property
    def content(self):
        """
        Gets the content of this UsageOutputV1.
        Amount of content usages during the specified time period

        :return: The content of this UsageOutputV1.
        :rtype: int
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this UsageOutputV1.
        Amount of content usages during the specified time period

        :param content: The content of this UsageOutputV1.
        :type: int
        """
        if content is None:
            raise ValueError("Invalid value for `content`, must not be `None`")

        self._content = content

    @property
    def credits(self):
        """
        Gets the credits of this UsageOutputV1.
        Amount of Data Lab Resource Credits consumed during the specified time period

        :return: The credits of this UsageOutputV1.
        :rtype: float
        """
        return self._credits

    @credits.setter
    def credits(self, credits):
        """
        Sets the credits of this UsageOutputV1.
        Amount of Data Lab Resource Credits consumed during the specified time period

        :param credits: The credits of this UsageOutputV1.
        :type: float
        """
        if credits is None:
            raise ValueError("Invalid value for `credits`, must not be `None`")

        self._credits = credits

    @property
    def identity(self):
        """
        Gets the identity of this UsageOutputV1.
        User name who initiated the request. Only present when aggregated by this \"User\"

        :return: The identity of this UsageOutputV1.
        :rtype: str
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """
        Sets the identity of this UsageOutputV1.
        User name who initiated the request. Only present when aggregated by this \"User\"

        :param identity: The identity of this UsageOutputV1.
        :type: str
        """

        self._identity = identity

    @property
    def identity_id(self):
        """
        Gets the identity_id of this UsageOutputV1.
        Guid of the user who initiated the request. Only present when aggregated by this \"User\"

        :return: The identity_id of this UsageOutputV1.
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this UsageOutputV1.
        Guid of the user who initiated the request. Only present when aggregated by this \"User\"

        :param identity_id: The identity_id of this UsageOutputV1.
        :type: str
        """

        self._identity_id = identity_id

    @property
    def prompts(self):
        """
        Gets the prompts of this UsageOutputV1.
        Amount of GenAI prompts consumed during the specified time period

        :return: The prompts of this UsageOutputV1.
        :rtype: int
        """
        return self._prompts

    @prompts.setter
    def prompts(self, prompts):
        """
        Sets the prompts of this UsageOutputV1.
        Amount of GenAI prompts consumed during the specified time period

        :param prompts: The prompts of this UsageOutputV1.
        :type: int
        """
        if prompts is None:
            raise ValueError("Invalid value for `prompts`, must not be `None`")

        self._prompts = prompts

    @property
    def source_label(self):
        """
        Gets the source_label of this UsageOutputV1.
        Name of the source of the request. Only present when aggregated by \"Source\"

        :return: The source_label of this UsageOutputV1.
        :rtype: str
        """
        return self._source_label

    @source_label.setter
    def source_label(self, source_label):
        """
        Sets the source_label of this UsageOutputV1.
        Name of the source of the request. Only present when aggregated by \"Source\"

        :param source_label: The source_label of this UsageOutputV1.
        :type: str
        """

        self._source_label = source_label

    @property
    def source_url(self):
        """
        Gets the source_url of this UsageOutputV1.
        Url for the source of the request. Only present when aggregated by \"Source\"

        :return: The source_url of this UsageOutputV1.
        :rtype: str
        """
        return self._source_url

    @source_url.setter
    def source_url(self, source_url):
        """
        Sets the source_url of this UsageOutputV1.
        Url for the source of the request. Only present when aggregated by \"Source\"

        :param source_url: The source_url of this UsageOutputV1.
        :type: str
        """

        self._source_url = source_url

    @property
    def timestamp(self):
        """
        Gets the timestamp of this UsageOutputV1.
        An ISO-8601 timestamp of the day when the data was consumed. Only present when aggregated by \"Day\" or \"Month\"

        :return: The timestamp of this UsageOutputV1.
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this UsageOutputV1.
        An ISO-8601 timestamp of the day when the data was consumed. Only present when aggregated by \"Day\" or \"Month\"

        :param timestamp: The timestamp of this UsageOutputV1.
        :type: str
        """

        self._timestamp = timestamp

    @property
    def tokens(self):
        """
        Gets the tokens of this UsageOutputV1.
        Amount of GenAI tokens consumed during the specified time period

        :return: The tokens of this UsageOutputV1.
        :rtype: int
        """
        return self._tokens

    @tokens.setter
    def tokens(self, tokens):
        """
        Sets the tokens of this UsageOutputV1.
        Amount of GenAI tokens consumed during the specified time period

        :param tokens: The tokens of this UsageOutputV1.
        :type: int
        """
        if tokens is None:
            raise ValueError("Invalid value for `tokens`, must not be `None`")

        self._tokens = tokens

    @property
    def type(self):
        """
        Gets the type of this UsageOutputV1.
        The type of the request. Only present when aggregated by this \"Type\"

        :return: The type of this UsageOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this UsageOutputV1.
        The type of the request. Only present when aggregated by this \"Type\"

        :param type: The type of this UsageOutputV1.
        :type: str
        """

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UsageOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FormulaParameterOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'formula': 'str',
        'item': 'ItemSearchPreviewV1',
        'name': 'str',
        'unbound': 'bool'
    }

    attribute_map = {
        'formula': 'formula',
        'item': 'item',
        'name': 'name',
        'unbound': 'unbound'
    }

    def __init__(self, formula=None, item=None, name=None, unbound=False):
        """
        FormulaParameterOutputV1 - a model defined in Swagger
        """

        self._formula = None
        self._item = None
        self._name = None
        self._unbound = None

        if formula is not None:
          self.formula = formula
        if item is not None:
          self.item = item
        if name is not None:
          self.name = name
        if unbound is not None:
          self.unbound = unbound

    @property
    def formula(self):
        """
        Gets the formula of this FormulaParameterOutputV1.
        The formula that defines this parameter if it is unbound or a formula parameter

        :return: The formula of this FormulaParameterOutputV1.
        :rtype: str
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """
        Sets the formula of this FormulaParameterOutputV1.
        The formula that defines this parameter if it is unbound or a formula parameter

        :param formula: The formula of this FormulaParameterOutputV1.
        :type: str
        """

        self._formula = formula

    @property
    def item(self):
        """
        Gets the item of this FormulaParameterOutputV1.

        :return: The item of this FormulaParameterOutputV1.
        :rtype: ItemSearchPreviewV1
        """
        return self._item

    @item.setter
    def item(self, item):
        """
        Sets the item of this FormulaParameterOutputV1.

        :param item: The item of this FormulaParameterOutputV1.
        :type: ItemSearchPreviewV1
        """

        self._item = item

    @property
    def name(self):
        """
        Gets the name of this FormulaParameterOutputV1.
        The name of the parameter as used in the formula without the '$' prefix.

        :return: The name of this FormulaParameterOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FormulaParameterOutputV1.
        The name of the parameter as used in the formula without the '$' prefix.

        :param name: The name of this FormulaParameterOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def unbound(self):
        """
        Gets the unbound of this FormulaParameterOutputV1.
        Indicate the value of this parameter will be provided at runtime

        :return: The unbound of this FormulaParameterOutputV1.
        :rtype: bool
        """
        return self._unbound

    @unbound.setter
    def unbound(self, unbound):
        """
        Sets the unbound of this FormulaParameterOutputV1.
        Indicate the value of this parameter will be provided at runtime

        :param unbound: The unbound of this FormulaParameterOutputV1.
        :type: bool
        """

        self._unbound = unbound

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FormulaParameterOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class NumericDescriptionInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'creator_id': 'str',
        'icon': 'str',
        'max': 'float',
        'min': 'float',
        'name': 'str',
        'precision': 'float',
        'unit_of_measure': 'str',
        'updated_at': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'creator_id': 'creatorId',
        'icon': 'icon',
        'max': 'max',
        'min': 'min',
        'name': 'name',
        'precision': 'precision',
        'unit_of_measure': 'unitOfMeasure',
        'updated_at': 'updatedAt'
    }

    def __init__(self, created_at=None, creator_id=None, icon=None, max=None, min=None, name=None, precision=None, unit_of_measure=None, updated_at=None):
        """
        NumericDescriptionInputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._creator_id = None
        self._icon = None
        self._max = None
        self._min = None
        self._name = None
        self._precision = None
        self._unit_of_measure = None
        self._updated_at = None

        if created_at is not None:
          self.created_at = created_at
        if creator_id is not None:
          self.creator_id = creator_id
        if icon is not None:
          self.icon = icon
        if max is not None:
          self.max = max
        if min is not None:
          self.min = min
        if name is not None:
          self.name = name
        if precision is not None:
          self.precision = precision
        if unit_of_measure is not None:
          self.unit_of_measure = unit_of_measure
        if updated_at is not None:
          self.updated_at = updated_at

    @property
    def created_at(self):
        """
        Gets the created_at of this NumericDescriptionInputV1.
        The time the numeric description was created

        :return: The created_at of this NumericDescriptionInputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this NumericDescriptionInputV1.
        The time the numeric description was created

        :param created_at: The created_at of this NumericDescriptionInputV1.
        :type: str
        """

        self._created_at = created_at

    @property
    def creator_id(self):
        """
        Gets the creator_id of this NumericDescriptionInputV1.
        The creator of the numeric description

        :return: The creator_id of this NumericDescriptionInputV1.
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id):
        """
        Sets the creator_id of this NumericDescriptionInputV1.
        The creator of the numeric description

        :param creator_id: The creator_id of this NumericDescriptionInputV1.
        :type: str
        """

        self._creator_id = creator_id

    @property
    def icon(self):
        """
        Gets the icon of this NumericDescriptionInputV1.
        Icon of the numeric description

        :return: The icon of this NumericDescriptionInputV1.
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """
        Sets the icon of this NumericDescriptionInputV1.
        Icon of the numeric description

        :param icon: The icon of this NumericDescriptionInputV1.
        :type: str
        """

        self._icon = icon

    @property
    def max(self):
        """
        Gets the max of this NumericDescriptionInputV1.
        Maximum value of the numeric description

        :return: The max of this NumericDescriptionInputV1.
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this NumericDescriptionInputV1.
        Maximum value of the numeric description

        :param max: The max of this NumericDescriptionInputV1.
        :type: float
        """

        self._max = max

    @property
    def min(self):
        """
        Gets the min of this NumericDescriptionInputV1.
        Minimum value of the numeric description

        :return: The min of this NumericDescriptionInputV1.
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """
        Sets the min of this NumericDescriptionInputV1.
        Minimum value of the numeric description

        :param min: The min of this NumericDescriptionInputV1.
        :type: float
        """

        self._min = min

    @property
    def name(self):
        """
        Gets the name of this NumericDescriptionInputV1.
        Name of the numeric description

        :return: The name of this NumericDescriptionInputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NumericDescriptionInputV1.
        Name of the numeric description

        :param name: The name of this NumericDescriptionInputV1.
        :type: str
        """

        self._name = name

    @property
    def precision(self):
        """
        Gets the precision of this NumericDescriptionInputV1.
        Measurement precision of the specified unit of measure and min/max values eg: 0.1 for decimal precision

        :return: The precision of this NumericDescriptionInputV1.
        :rtype: float
        """
        return self._precision

    @precision.setter
    def precision(self, precision):
        """
        Sets the precision of this NumericDescriptionInputV1.
        Measurement precision of the specified unit of measure and min/max values eg: 0.1 for decimal precision

        :param precision: The precision of this NumericDescriptionInputV1.
        :type: float
        """

        self._precision = precision

    @property
    def unit_of_measure(self):
        """
        Gets the unit_of_measure of this NumericDescriptionInputV1.
        The unit of the numeric description

        :return: The unit_of_measure of this NumericDescriptionInputV1.
        :rtype: str
        """
        return self._unit_of_measure

    @unit_of_measure.setter
    def unit_of_measure(self, unit_of_measure):
        """
        Sets the unit_of_measure of this NumericDescriptionInputV1.
        The unit of the numeric description

        :param unit_of_measure: The unit_of_measure of this NumericDescriptionInputV1.
        :type: str
        """

        self._unit_of_measure = unit_of_measure

    @property
    def updated_at(self):
        """
        Gets the updated_at of this NumericDescriptionInputV1.
        The time the numeric description was last updated

        :return: The updated_at of this NumericDescriptionInputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this NumericDescriptionInputV1.
        The time the numeric description was last updated

        :param updated_at: The updated_at of this NumericDescriptionInputV1.
        :type: str
        """

        self._updated_at = updated_at

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, NumericDescriptionInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ScalingTableUUIDColumnSearchV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_definition_id': 'str',
        'is_include': 'bool',
        'row_ids': 'list[str]',
        'search_type': 'str',
        'table_definition_id': 'str',
        'types': 'list[str]'
    }

    attribute_map = {
        'column_definition_id': 'columnDefinitionId',
        'is_include': 'isInclude',
        'row_ids': 'rowIds',
        'search_type': 'searchType',
        'table_definition_id': 'tableDefinitionId',
        'types': 'types'
    }

    def __init__(self, column_definition_id=None, is_include=None, row_ids=None, search_type=None, table_definition_id=None, types=None):
        """
        ScalingTableUUIDColumnSearchV1 - a model defined in Swagger
        """

        self._column_definition_id = None
        self._is_include = None
        self._row_ids = None
        self._search_type = None
        self._table_definition_id = None
        self._types = None

        if column_definition_id is not None:
          self.column_definition_id = column_definition_id
        if is_include is not None:
          self.is_include = is_include
        if row_ids is not None:
          self.row_ids = row_ids
        if search_type is not None:
          self.search_type = search_type
        if table_definition_id is not None:
          self.table_definition_id = table_definition_id
        if types is not None:
          self.types = types

    @property
    def column_definition_id(self):
        """
        Gets the column_definition_id of this ScalingTableUUIDColumnSearchV1.
        The column definition ID whose items will be searched

        :return: The column_definition_id of this ScalingTableUUIDColumnSearchV1.
        :rtype: str
        """
        return self._column_definition_id

    @column_definition_id.setter
    def column_definition_id(self, column_definition_id):
        """
        Sets the column_definition_id of this ScalingTableUUIDColumnSearchV1.
        The column definition ID whose items will be searched

        :param column_definition_id: The column_definition_id of this ScalingTableUUIDColumnSearchV1.
        :type: str
        """
        if column_definition_id is None:
            raise ValueError("Invalid value for `column_definition_id`, must not be `None`")

        self._column_definition_id = column_definition_id

    @property
    def is_include(self):
        """
        Gets the is_include of this ScalingTableUUIDColumnSearchV1.
        If true, the items found by this search will be included in the output. If false, then the results will be excluded from the output (even if found by another search)

        :return: The is_include of this ScalingTableUUIDColumnSearchV1.
        :rtype: bool
        """
        return self._is_include

    @is_include.setter
    def is_include(self, is_include):
        """
        Sets the is_include of this ScalingTableUUIDColumnSearchV1.
        If true, the items found by this search will be included in the output. If false, then the results will be excluded from the output (even if found by another search)

        :param is_include: The is_include of this ScalingTableUUIDColumnSearchV1.
        :type: bool
        """
        if is_include is None:
            raise ValueError("Invalid value for `is_include`, must not be `None`")

        self._is_include = is_include

    @property
    def row_ids(self):
        """
        Gets the row_ids of this ScalingTableUUIDColumnSearchV1.
        The row ids, either the item ids that identify the rows of the table or the item id and datum id pair separated by '|', that filter the search to only those rows.

        :return: The row_ids of this ScalingTableUUIDColumnSearchV1.
        :rtype: list[str]
        """
        return self._row_ids

    @row_ids.setter
    def row_ids(self, row_ids):
        """
        Sets the row_ids of this ScalingTableUUIDColumnSearchV1.
        The row ids, either the item ids that identify the rows of the table or the item id and datum id pair separated by '|', that filter the search to only those rows.

        :param row_ids: The row_ids of this ScalingTableUUIDColumnSearchV1.
        :type: list[str]
        """

        self._row_ids = row_ids

    @property
    def search_type(self):
        """
        Gets the search_type of this ScalingTableUUIDColumnSearchV1.
        The type of search

        :return: The search_type of this ScalingTableUUIDColumnSearchV1.
        :rtype: str
        """
        return self._search_type

    @search_type.setter
    def search_type(self, search_type):
        """
        Sets the search_type of this ScalingTableUUIDColumnSearchV1.
        The type of search

        :param search_type: The search_type of this ScalingTableUUIDColumnSearchV1.
        :type: str
        """
        if search_type is None:
            raise ValueError("Invalid value for `search_type`, must not be `None`")
        allowed_values = ["SWAP_ACROSS_ASSETS", "FIXED_LIST", "PROPERTY", "MATERIALIZED_TABLE_UUID_COLUMN", "HIERARCHY"]
        if search_type not in allowed_values:
            raise ValueError(
                "Invalid value for `search_type` ({0}), must be one of {1}"
                .format(search_type, allowed_values)
            )

        self._search_type = search_type

    @property
    def table_definition_id(self):
        """
        Gets the table_definition_id of this ScalingTableUUIDColumnSearchV1.
        The table definition ID whose column items will be searched

        :return: The table_definition_id of this ScalingTableUUIDColumnSearchV1.
        :rtype: str
        """
        return self._table_definition_id

    @table_definition_id.setter
    def table_definition_id(self, table_definition_id):
        """
        Sets the table_definition_id of this ScalingTableUUIDColumnSearchV1.
        The table definition ID whose column items will be searched

        :param table_definition_id: The table_definition_id of this ScalingTableUUIDColumnSearchV1.
        :type: str
        """
        if table_definition_id is None:
            raise ValueError("Invalid value for `table_definition_id`, must not be `None`")

        self._table_definition_id = table_definition_id

    @property
    def types(self):
        """
        Gets the types of this ScalingTableUUIDColumnSearchV1.
        The types of items that will be searched, defaults to all types if not provided

        :return: The types of this ScalingTableUUIDColumnSearchV1.
        :rtype: list[str]
        """
        return self._types

    @types.setter
    def types(self, types):
        """
        Sets the types of this ScalingTableUUIDColumnSearchV1.
        The types of items that will be searched, defaults to all types if not provided

        :param types: The types of this ScalingTableUUIDColumnSearchV1.
        :type: list[str]
        """

        self._types = types

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ScalingTableUUIDColumnSearchV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelApplicationMappingV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_id': 'str',
        'feature_id': 'str',
        'item_id_input': 'str',
        'numeric_input': 'float',
        'numeric_input_uom': 'str',
        'text_input': 'str'
    }

    attribute_map = {
        'column_id': 'columnId',
        'feature_id': 'featureId',
        'item_id_input': 'itemIdInput',
        'numeric_input': 'numericInput',
        'numeric_input_uom': 'numericInputUom',
        'text_input': 'textInput'
    }

    def __init__(self, column_id=None, feature_id=None, item_id_input=None, numeric_input=None, numeric_input_uom=None, text_input=None):
        """
        ModelApplicationMappingV1 - a model defined in Swagger
        """

        self._column_id = None
        self._feature_id = None
        self._item_id_input = None
        self._numeric_input = None
        self._numeric_input_uom = None
        self._text_input = None

        if column_id is not None:
          self.column_id = column_id
        if feature_id is not None:
          self.feature_id = feature_id
        if item_id_input is not None:
          self.item_id_input = item_id_input
        if numeric_input is not None:
          self.numeric_input = numeric_input
        if numeric_input_uom is not None:
          self.numeric_input_uom = numeric_input_uom
        if text_input is not None:
          self.text_input = text_input

    @property
    def column_id(self):
        """
        Gets the column_id of this ModelApplicationMappingV1.
        Column definition ID

        :return: The column_id of this ModelApplicationMappingV1.
        :rtype: str
        """
        return self._column_id

    @column_id.setter
    def column_id(self, column_id):
        """
        Sets the column_id of this ModelApplicationMappingV1.
        Column definition ID

        :param column_id: The column_id of this ModelApplicationMappingV1.
        :type: str
        """

        self._column_id = column_id

    @property
    def feature_id(self):
        """
        Gets the feature_id of this ModelApplicationMappingV1.
        Feature

        :return: The feature_id of this ModelApplicationMappingV1.
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """
        Sets the feature_id of this ModelApplicationMappingV1.
        Feature

        :param feature_id: The feature_id of this ModelApplicationMappingV1.
        :type: str
        """

        self._feature_id = feature_id

    @property
    def item_id_input(self):
        """
        Gets the item_id_input of this ModelApplicationMappingV1.
        Item ID input value

        :return: The item_id_input of this ModelApplicationMappingV1.
        :rtype: str
        """
        return self._item_id_input

    @item_id_input.setter
    def item_id_input(self, item_id_input):
        """
        Sets the item_id_input of this ModelApplicationMappingV1.
        Item ID input value

        :param item_id_input: The item_id_input of this ModelApplicationMappingV1.
        :type: str
        """

        self._item_id_input = item_id_input

    @property
    def numeric_input(self):
        """
        Gets the numeric_input of this ModelApplicationMappingV1.
        Numeric literal input value

        :return: The numeric_input of this ModelApplicationMappingV1.
        :rtype: float
        """
        return self._numeric_input

    @numeric_input.setter
    def numeric_input(self, numeric_input):
        """
        Sets the numeric_input of this ModelApplicationMappingV1.
        Numeric literal input value

        :param numeric_input: The numeric_input of this ModelApplicationMappingV1.
        :type: float
        """

        self._numeric_input = numeric_input

    @property
    def numeric_input_uom(self):
        """
        Gets the numeric_input_uom of this ModelApplicationMappingV1.
        Numeric literal input unit of measure

        :return: The numeric_input_uom of this ModelApplicationMappingV1.
        :rtype: str
        """
        return self._numeric_input_uom

    @numeric_input_uom.setter
    def numeric_input_uom(self, numeric_input_uom):
        """
        Sets the numeric_input_uom of this ModelApplicationMappingV1.
        Numeric literal input unit of measure

        :param numeric_input_uom: The numeric_input_uom of this ModelApplicationMappingV1.
        :type: str
        """

        self._numeric_input_uom = numeric_input_uom

    @property
    def text_input(self):
        """
        Gets the text_input of this ModelApplicationMappingV1.
        Text literal input value

        :return: The text_input of this ModelApplicationMappingV1.
        :rtype: str
        """
        return self._text_input

    @text_input.setter
    def text_input(self, text_input):
        """
        Sets the text_input of this ModelApplicationMappingV1.
        Text literal input value

        :param text_input: The text_input of this ModelApplicationMappingV1.
        :type: str
        """

        self._text_input = text_input

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelApplicationMappingV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ThresholdOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_generated': 'bool',
        'item': 'ItemPreviewV1',
        'priority': 'PriorityV1',
        'value': 'ScalarValueOutputV1'
    }

    attribute_map = {
        'is_generated': 'isGenerated',
        'item': 'item',
        'priority': 'priority',
        'value': 'value'
    }

    def __init__(self, is_generated=None, item=None, priority=None, value=None):
        """
        ThresholdOutputV1 - a model defined in Swagger
        """

        self._is_generated = None
        self._item = None
        self._priority = None
        self._value = None

        if is_generated is not None:
          self.is_generated = is_generated
        if item is not None:
          self.item = item
        if priority is not None:
          self.priority = priority
        if value is not None:
          self.value = value

    @property
    def is_generated(self):
        """
        Gets the is_generated of this ThresholdOutputV1.

        :return: The is_generated of this ThresholdOutputV1.
        :rtype: bool
        """
        return self._is_generated

    @is_generated.setter
    def is_generated(self, is_generated):
        """
        Sets the is_generated of this ThresholdOutputV1.

        :param is_generated: The is_generated of this ThresholdOutputV1.
        :type: bool
        """

        self._is_generated = is_generated

    @property
    def item(self):
        """
        Gets the item of this ThresholdOutputV1.

        :return: The item of this ThresholdOutputV1.
        :rtype: ItemPreviewV1
        """
        return self._item

    @item.setter
    def item(self, item):
        """
        Sets the item of this ThresholdOutputV1.

        :param item: The item of this ThresholdOutputV1.
        :type: ItemPreviewV1
        """

        self._item = item

    @property
    def priority(self):
        """
        Gets the priority of this ThresholdOutputV1.

        :return: The priority of this ThresholdOutputV1.
        :rtype: PriorityV1
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this ThresholdOutputV1.

        :param priority: The priority of this ThresholdOutputV1.
        :type: PriorityV1
        """

        self._priority = priority

    @property
    def value(self):
        """
        Gets the value of this ThresholdOutputV1.

        :return: The value of this ThresholdOutputV1.
        :rtype: ScalarValueOutputV1
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ThresholdOutputV1.

        :param value: The value of this ThresholdOutputV1.
        :type: ScalarValueOutputV1
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ThresholdOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ContextNumericInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'datum_id': 'str',
        'end_time': 'str',
        'numeric_description_id': 'str',
        'start_time': 'str',
        'table_id': 'str',
        'value': 'float'
    }

    attribute_map = {
        'datum_id': 'datumId',
        'end_time': 'endTime',
        'numeric_description_id': 'numericDescriptionId',
        'start_time': 'startTime',
        'table_id': 'tableId',
        'value': 'value'
    }

    def __init__(self, datum_id=None, end_time=None, numeric_description_id=None, start_time=None, table_id=None, value=None):
        """
        ContextNumericInputV1 - a model defined in Swagger
        """

        self._datum_id = None
        self._end_time = None
        self._numeric_description_id = None
        self._start_time = None
        self._table_id = None
        self._value = None

        if datum_id is not None:
          self.datum_id = datum_id
        if end_time is not None:
          self.end_time = end_time
        if numeric_description_id is not None:
          self.numeric_description_id = numeric_description_id
        if start_time is not None:
          self.start_time = start_time
        if table_id is not None:
          self.table_id = table_id
        if value is not None:
          self.value = value

    @property
    def datum_id(self):
        """
        Gets the datum_id of this ContextNumericInputV1.
        If provided, the ID of a more specific aspect of the Item to associate with the label, such as the ID of a capsule

        :return: The datum_id of this ContextNumericInputV1.
        :rtype: str
        """
        return self._datum_id

    @datum_id.setter
    def datum_id(self, datum_id):
        """
        Sets the datum_id of this ContextNumericInputV1.
        If provided, the ID of a more specific aspect of the Item to associate with the label, such as the ID of a capsule

        :param datum_id: The datum_id of this ContextNumericInputV1.
        :type: str
        """

        self._datum_id = datum_id

    @property
    def end_time(self):
        """
        Gets the end_time of this ContextNumericInputV1.
        The end time of the numeric in the form of an ISO8601 timestamp. If provided, start time must also be provided.

        :return: The end_time of this ContextNumericInputV1.
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ContextNumericInputV1.
        The end time of the numeric in the form of an ISO8601 timestamp. If provided, start time must also be provided.

        :param end_time: The end_time of this ContextNumericInputV1.
        :type: str
        """

        self._end_time = end_time

    @property
    def numeric_description_id(self):
        """
        Gets the numeric_description_id of this ContextNumericInputV1.
        The ID of the numeric description

        :return: The numeric_description_id of this ContextNumericInputV1.
        :rtype: str
        """
        return self._numeric_description_id

    @numeric_description_id.setter
    def numeric_description_id(self, numeric_description_id):
        """
        Sets the numeric_description_id of this ContextNumericInputV1.
        The ID of the numeric description

        :param numeric_description_id: The numeric_description_id of this ContextNumericInputV1.
        :type: str
        """

        self._numeric_description_id = numeric_description_id

    @property
    def start_time(self):
        """
        Gets the start_time of this ContextNumericInputV1.
        The start time of the numeric in the form of an ISO8601 timestamp. If provided, end time must also be provided.

        :return: The start_time of this ContextNumericInputV1.
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ContextNumericInputV1.
        The start time of the numeric in the form of an ISO8601 timestamp. If provided, end time must also be provided.

        :param start_time: The start_time of this ContextNumericInputV1.
        :type: str
        """

        self._start_time = start_time

    @property
    def table_id(self):
        """
        Gets the table_id of this ContextNumericInputV1.
        The table ID of the context

        :return: The table_id of this ContextNumericInputV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this ContextNumericInputV1.
        The table ID of the context

        :param table_id: The table_id of this ContextNumericInputV1.
        :type: str
        """

        self._table_id = table_id

    @property
    def value(self):
        """
        Gets the value of this ContextNumericInputV1.
        The value of the numeric context

        :return: The value of this ContextNumericInputV1.
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ContextNumericInputV1.
        The value of the numeric context

        :param value: The value of this ContextNumericInputV1.
        :type: float
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ContextNumericInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class InstanceOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'inputs': 'list[ModelApplicationMappingV1]',
        'instance_id': 'str',
        'model_id': 'str',
        'outputs': 'list[InstanceOutputMappingV1]'
    }

    attribute_map = {
        'inputs': 'inputs',
        'instance_id': 'instanceId',
        'model_id': 'modelId',
        'outputs': 'outputs'
    }

    def __init__(self, inputs=None, instance_id=None, model_id=None, outputs=None):
        """
        InstanceOutputV1 - a model defined in Swagger
        """

        self._inputs = None
        self._instance_id = None
        self._model_id = None
        self._outputs = None

        if inputs is not None:
          self.inputs = inputs
        if instance_id is not None:
          self.instance_id = instance_id
        if model_id is not None:
          self.model_id = model_id
        if outputs is not None:
          self.outputs = outputs

    @property
    def inputs(self):
        """
        Gets the inputs of this InstanceOutputV1.
        Literals or Item IDs applied to the instantiated model

        :return: The inputs of this InstanceOutputV1.
        :rtype: list[ModelApplicationMappingV1]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """
        Sets the inputs of this InstanceOutputV1.
        Literals or Item IDs applied to the instantiated model

        :param inputs: The inputs of this InstanceOutputV1.
        :type: list[ModelApplicationMappingV1]
        """

        self._inputs = inputs

    @property
    def instance_id(self):
        """
        Gets the instance_id of this InstanceOutputV1.
        ID of the instance

        :return: The instance_id of this InstanceOutputV1.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """
        Sets the instance_id of this InstanceOutputV1.
        ID of the instance

        :param instance_id: The instance_id of this InstanceOutputV1.
        :type: str
        """

        self._instance_id = instance_id

    @property
    def model_id(self):
        """
        Gets the model_id of this InstanceOutputV1.
        ID of the instantiated model

        :return: The model_id of this InstanceOutputV1.
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """
        Sets the model_id of this InstanceOutputV1.
        ID of the instantiated model

        :param model_id: The model_id of this InstanceOutputV1.
        :type: str
        """

        self._model_id = model_id

    @property
    def outputs(self):
        """
        Gets the outputs of this InstanceOutputV1.
        Derived outputs created by the instantiated model

        :return: The outputs of this InstanceOutputV1.
        :rtype: list[InstanceOutputMappingV1]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """
        Sets the outputs of this InstanceOutputV1.
        Derived outputs created by the instantiated model

        :param outputs: The outputs of this InstanceOutputV1.
        :type: list[InstanceOutputMappingV1]
        """

        self._outputs = outputs

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InstanceOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleTextExtractorInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_index': 'int',
        'regex': 'str'
    }

    attribute_map = {
        'column_index': 'columnIndex',
        'regex': 'regex'
    }

    def __init__(self, column_index=None, regex=None):
        """
        ColumnRuleTextExtractorInputV1 - a model defined in Swagger
        """

        self._column_index = None
        self._regex = None

        if column_index is not None:
          self.column_index = column_index
        if regex is not None:
          self.regex = regex

    @property
    def column_index(self):
        """
        Gets the column_index of this ColumnRuleTextExtractorInputV1.
        The index of the column that references the string to extract information from. The column index is 1-based

        :return: The column_index of this ColumnRuleTextExtractorInputV1.
        :rtype: int
        """
        return self._column_index

    @column_index.setter
    def column_index(self, column_index):
        """
        Sets the column_index of this ColumnRuleTextExtractorInputV1.
        The index of the column that references the string to extract information from. The column index is 1-based

        :param column_index: The column_index of this ColumnRuleTextExtractorInputV1.
        :type: int
        """
        if column_index is None:
            raise ValueError("Invalid value for `column_index`, must not be `None`")

        self._column_index = column_index

    @property
    def regex(self):
        """
        Gets the regex of this ColumnRuleTextExtractorInputV1.
        The regular expression to apply to the column to extract information from. If the regular expression has no capture groups, () are added around the entire string to form a capturegroup including everything in the passed in string. Only a single capture group is supported.

        :return: The regex of this ColumnRuleTextExtractorInputV1.
        :rtype: str
        """
        return self._regex

    @regex.setter
    def regex(self, regex):
        """
        Sets the regex of this ColumnRuleTextExtractorInputV1.
        The regular expression to apply to the column to extract information from. If the regular expression has no capture groups, () are added around the entire string to form a capturegroup including everything in the passed in string. Only a single capture group is supported.

        :param regex: The regex of this ColumnRuleTextExtractorInputV1.
        :type: str
        """
        if regex is None:
            raise ValueError("Invalid value for `regex`, must not be `None`")

        self._regex = regex

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleTextExtractorInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class FixedListSearchV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_include': 'bool',
        'item_ids': 'list[str]',
        'search_type': 'str'
    }

    attribute_map = {
        'is_include': 'isInclude',
        'item_ids': 'itemIds',
        'search_type': 'searchType'
    }

    def __init__(self, is_include=None, item_ids=None, search_type=None):
        """
        FixedListSearchV1 - a model defined in Swagger
        """

        self._is_include = None
        self._item_ids = None
        self._search_type = None

        if is_include is not None:
          self.is_include = is_include
        if item_ids is not None:
          self.item_ids = item_ids
        if search_type is not None:
          self.search_type = search_type

    @property
    def is_include(self):
        """
        Gets the is_include of this FixedListSearchV1.
        If true the items found by this configuration will be included in the output, if false then the results will be excluded from the output (even if found by another finder configuration)

        :return: The is_include of this FixedListSearchV1.
        :rtype: bool
        """
        return self._is_include

    @is_include.setter
    def is_include(self, is_include):
        """
        Sets the is_include of this FixedListSearchV1.
        If true the items found by this configuration will be included in the output, if false then the results will be excluded from the output (even if found by another finder configuration)

        :param is_include: The is_include of this FixedListSearchV1.
        :type: bool
        """
        if is_include is None:
            raise ValueError("Invalid value for `is_include`, must not be `None`")

        self._is_include = is_include

    @property
    def item_ids(self):
        """
        Gets the item_ids of this FixedListSearchV1.
        A list of item IDs to always include or exclude in the output. Useful for including or excluding outliers that are not easily found via one of the other finder configurations

        :return: The item_ids of this FixedListSearchV1.
        :rtype: list[str]
        """
        return self._item_ids

    @item_ids.setter
    def item_ids(self, item_ids):
        """
        Sets the item_ids of this FixedListSearchV1.
        A list of item IDs to always include or exclude in the output. Useful for including or excluding outliers that are not easily found via one of the other finder configurations

        :param item_ids: The item_ids of this FixedListSearchV1.
        :type: list[str]
        """
        if item_ids is None:
            raise ValueError("Invalid value for `item_ids`, must not be `None`")

        self._item_ids = item_ids

    @property
    def search_type(self):
        """
        Gets the search_type of this FixedListSearchV1.
        The type of finder

        :return: The search_type of this FixedListSearchV1.
        :rtype: str
        """
        return self._search_type

    @search_type.setter
    def search_type(self, search_type):
        """
        Sets the search_type of this FixedListSearchV1.
        The type of finder

        :param search_type: The search_type of this FixedListSearchV1.
        :type: str
        """
        if search_type is None:
            raise ValueError("Invalid value for `search_type`, must not be `None`")
        allowed_values = ["SWAP_ACROSS_ASSETS", "FIXED_LIST", "PROPERTY", "MATERIALIZED_TABLE_UUID_COLUMN", "HIERARCHY"]
        if search_type not in allowed_values:
            raise ValueError(
                "Invalid value for `search_type` ({0}), must be one of {1}"
                .format(search_type, allowed_values)
            )

        self._search_type = search_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FixedListSearchV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.58.1-v202509300326-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class MonitoredSignalLastRunStateOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cursor_key': 'int',
        'error_count': 'int',
        'last_certain_sample': 'SampleOutputV1',
        'last_error': 'str',
        'last_error_time_created': 'int',
        'signal_guid': 'str',
        'uncertain_samples': 'list[SampleOutputV1]'
    }

    attribute_map = {
        'cursor_key': 'cursorKey',
        'error_count': 'errorCount',
        'last_certain_sample': 'lastCertainSample',
        'last_error': 'lastError',
        'last_error_time_created': 'lastErrorTimeCreated',
        'signal_guid': 'signalGuid',
        'uncertain_samples': 'uncertainSamples'
    }

    def __init__(self, cursor_key=None, error_count=None, last_certain_sample=None, last_error=None, last_error_time_created=None, signal_guid=None, uncertain_samples=None):
        """
        MonitoredSignalLastRunStateOutputV1 - a model defined in Swagger
        """

        self._cursor_key = None
        self._error_count = None
        self._last_certain_sample = None
        self._last_error = None
        self._last_error_time_created = None
        self._signal_guid = None
        self._uncertain_samples = None

        if cursor_key is not None:
          self.cursor_key = cursor_key
        if error_count is not None:
          self.error_count = error_count
        if last_certain_sample is not None:
          self.last_certain_sample = last_certain_sample
        if last_error is not None:
          self.last_error = last_error
        if last_error_time_created is not None:
          self.last_error_time_created = last_error_time_created
        if signal_guid is not None:
          self.signal_guid = signal_guid
        if uncertain_samples is not None:
          self.uncertain_samples = uncertain_samples

    @property
    def cursor_key(self):
        """
        Gets the cursor_key of this MonitoredSignalLastRunStateOutputV1.

        :return: The cursor_key of this MonitoredSignalLastRunStateOutputV1.
        :rtype: int
        """
        return self._cursor_key

    @cursor_key.setter
    def cursor_key(self, cursor_key):
        """
        Sets the cursor_key of this MonitoredSignalLastRunStateOutputV1.

        :param cursor_key: The cursor_key of this MonitoredSignalLastRunStateOutputV1.
        :type: int
        """

        self._cursor_key = cursor_key

    @property
    def error_count(self):
        """
        Gets the error_count of this MonitoredSignalLastRunStateOutputV1.

        :return: The error_count of this MonitoredSignalLastRunStateOutputV1.
        :rtype: int
        """
        return self._error_count

    @error_count.setter
    def error_count(self, error_count):
        """
        Sets the error_count of this MonitoredSignalLastRunStateOutputV1.

        :param error_count: The error_count of this MonitoredSignalLastRunStateOutputV1.
        :type: int
        """

        self._error_count = error_count

    @property
    def last_certain_sample(self):
        """
        Gets the last_certain_sample of this MonitoredSignalLastRunStateOutputV1.

        :return: The last_certain_sample of this MonitoredSignalLastRunStateOutputV1.
        :rtype: SampleOutputV1
        """
        return self._last_certain_sample

    @last_certain_sample.setter
    def last_certain_sample(self, last_certain_sample):
        """
        Sets the last_certain_sample of this MonitoredSignalLastRunStateOutputV1.

        :param last_certain_sample: The last_certain_sample of this MonitoredSignalLastRunStateOutputV1.
        :type: SampleOutputV1
        """

        self._last_certain_sample = last_certain_sample

    @property
    def last_error(self):
        """
        Gets the last_error of this MonitoredSignalLastRunStateOutputV1.

        :return: The last_error of this MonitoredSignalLastRunStateOutputV1.
        :rtype: str
        """
        return self._last_error

    @last_error.setter
    def last_error(self, last_error):
        """
        Sets the last_error of this MonitoredSignalLastRunStateOutputV1.

        :param last_error: The last_error of this MonitoredSignalLastRunStateOutputV1.
        :type: str
        """

        self._last_error = last_error

    @property
    def last_error_time_created(self):
        """
        Gets the last_error_time_created of this MonitoredSignalLastRunStateOutputV1.

        :return: The last_error_time_created of this MonitoredSignalLastRunStateOutputV1.
        :rtype: int
        """
        return self._last_error_time_created

    @last_error_time_created.setter
    def last_error_time_created(self, last_error_time_created):
        """
        Sets the last_error_time_created of this MonitoredSignalLastRunStateOutputV1.

        :param last_error_time_created: The last_error_time_created of this MonitoredSignalLastRunStateOutputV1.
        :type: int
        """

        self._last_error_time_created = last_error_time_created

    @property
    def signal_guid(self):
        """
        Gets the signal_guid of this MonitoredSignalLastRunStateOutputV1.

        :return: The signal_guid of this MonitoredSignalLastRunStateOutputV1.
        :rtype: str
        """
        return self._signal_guid

    @signal_guid.setter
    def signal_guid(self, signal_guid):
        """
        Sets the signal_guid of this MonitoredSignalLastRunStateOutputV1.

        :param signal_guid: The signal_guid of this MonitoredSignalLastRunStateOutputV1.
        :type: str
        """

        self._signal_guid = signal_guid

    @property
    def uncertain_samples(self):
        """
        Gets the uncertain_samples of this MonitoredSignalLastRunStateOutputV1.

        :return: The uncertain_samples of this MonitoredSignalLastRunStateOutputV1.
        :rtype: list[SampleOutputV1]
        """
        return self._uncertain_samples

    @uncertain_samples.setter
    def uncertain_samples(self, uncertain_samples):
        """
        Sets the uncertain_samples of this MonitoredSignalLastRunStateOutputV1.

        :param uncertain_samples: The uncertain_samples of this MonitoredSignalLastRunStateOutputV1.
        :type: list[SampleOutputV1]
        """

        self._uncertain_samples = uncertain_samples

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, MonitoredSignalLastRunStateOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
